/*
 * This file is part of the SPiC Project SPiChess  (https://gitlab.cs.fau.de/i4/spic/chess).
 * Copyright (c) 2017 - 2020 by Bernhard Heinloth
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef CHESS_OPENINGS_HELPER_H
#define CHESS_OPENINGS_HELPER_H

#define OPENING_IS_VALID(X) ((opening_invalid[(X)/8] & (1 << ((X) % 8))) == 0)
#define OPENING_INVALIDATE(X) do { opening_invalid[(X)/8] |= (1 << ((X) % 8)); } while(0)
#define OPENING_FROM_X(O,M) (((pgm_read_byte(&openings[O][(M) * 2 - 2])) >> 4) & 7)
#define OPENING_FROM_Y(O,M) (pgm_read_byte(&openings[O][(M) * 2 - 2]) & 7)
#define OPENING_TO_X(O,M) (((pgm_read_byte(&openings[O][(M) * 2 - 1])) >> 4) & 7)
#define OPENING_TO_Y(O,M) (pgm_read_byte(&openings[O][(M) * 2 - 1]) & 7)
#define OPENING_NONE (0xff)

#define A1 0x00
#define A2 0x01
#define A3 0x02
#define A4 0x03
#define A5 0x04
#define A6 0x05
#define A7 0x06
#define A8 0x07

#define B1 0x10
#define B2 0x11
#define B3 0x12
#define B4 0x13
#define B5 0x14
#define B6 0x15
#define B7 0x16
#define B8 0x17

#define C1 0x20
#define C2 0x21
#define C3 0x22
#define C4 0x23
#define C5 0x24
#define C6 0x25
#define C7 0x26
#define C8 0x27

#define D1 0x30
#define D2 0x31
#define D3 0x32
#define D4 0x33
#define D5 0x34
#define D6 0x35
#define D7 0x36
#define D8 0x37

#define E1 0x40
#define E2 0x41
#define E3 0x42
#define E4 0x43
#define E5 0x44
#define E6 0x45
#define E7 0x46
#define E8 0x47

#define F1 0x50
#define F2 0x51
#define F3 0x52
#define F4 0x53
#define F5 0x54
#define F6 0x55
#define F7 0x56
#define F8 0x57

#define G1 0x60
#define G2 0x61
#define G3 0x62
#define G4 0x63
#define G5 0x64
#define G6 0x65
#define G7 0x66
#define G8 0x67

#define H1 0x70
#define H2 0x71
#define H3 0x72
#define H4 0x73
#define H5 0x74
#define H6 0x75
#define H7 0x76
#define H8 0x77

#define XX 0xff

#endif
